@@ -31,9 +31,7 @@ describe 'basic ec2api' do
           class { '::ec2api::keystone::authtoken':
             password => 'a_big_secret',
           }
-          class { '::ec2api::api':
-            keystone_url => 'http://127.0.0.1:5000/v2',
-          }
+          class { '::ec2api::api': }
           include ::ec2api::metadata
         }
         default: {
@@ -47,5 +45,14 @@ describe 'basic ec2api' do
       apply_manifest(pp, :catch_changes => true)
     end
 
+    if os[:family].casecmp('RedHat') == 0
+      describe port(8788) do
+        it { is_expected.to be_listening }
+      end
+      describe port(8789) do
+        it { is_expected.to be_listening }
+      end
+    end
+
   end
 end
